@@ -8,6 +8,8 @@
 
 #define QT_FEATURE_webengine_system_gbm 1
 
+#define QT_FEATURE_webengine_webrtc_system_openh264 -1
+
 #define QT_FEATURE_webengine_printing_and_pdf 1
 
 #define QT_FEATURE_webengine_pepper_plugins 1
@@ -28,3 +30,5 @@
 
 #define QT_FEATURE_webengine_vaapi 1
 
+#define QT_FEATURE_webengine_arm64_udot_support -1
+
